﻿using System;
using System.ComponentModel.Composition;
using Microsoft.Practices.Prism.Regions;
using Telerik.Windows.Controls;
using System.Linq;

namespace DiagramsAndPrism
{
	[Export]
	public class RadDiagramRegionAdapter : RegionAdapterBase<RadDiagram>
	{
		[ImportingConstructor]
		public RadDiagramRegionAdapter([Import] Microsoft.Practices.Prism.Regions.IRegionBehaviorFactory regionBehaviorFactory)
			: base(regionBehaviorFactory)
		{
		}

		protected override void Adapt(IRegion region, RadDiagram regionTarget)
		{
			if (region == null)
			{
				throw new ArgumentNullException("region");
			}

			if (regionTarget == null)
			{
				throw new ArgumentNullException("regionTarget");
			}

			bool isSourceSet = regionTarget.Items.Count > 0;
			if (isSourceSet)
			{
				throw new InvalidOperationException("RadDiagram already has a source.");
			}

			region.ActiveViews.CollectionChanged += (s, e) =>
			{
				if (e.NewItems != null)
				{
					foreach (var item in e.NewItems)
					{
						regionTarget.Items.Add(item);
					}
				}
			};

			region.Views.CollectionChanged += (s, e) =>
			{
				if (e.NewItems != null)
				{
					foreach (var view in e.NewItems)
					{
						region.Activate(view);
					}
				}
			};
		}

		protected override IRegion CreateRegion()
		{
			return new AllActiveRegion();
		}
	}
}
